@@ -432,7 +432,12 @@ class Base(Controller):
                 "help" : "Number of recent files to show",
                 "action" : "store",
                 "default" : 25
-            })
+            }),
+            (['-f','--filter'],{
+                "help" : "Filter the files by this int",
+                "action" : "store",
+                "default" : 0
+            }),
         ]
     )
     def s3(self):
@@ -442,6 +447,7 @@ class Base(Controller):
 
         # ls actions for all dongle ids
         if self.app.pargs.action == 'ls':
+            filter = self.app.pargs.__dict__.get('filter') or self.app.pargs.__dict__.get('f') or 0
             
             from ..ext.aws_s3 import get_drives
             show_n = int(self.app.pargs.__dict__.get('show_n') or self.app.pargs.__dict__.get('n'))
@@ -450,7 +456,7 @@ class Base(Controller):
                 get_drives(self.app.pargs.target, show_n=show_n)
             else:
                 num_segments = self.app.pargs.__dict__.get('n') or self.app.pargs.__dict__.get('num_segments')
-                get_drives(self.app.pargs.target, show_n=show_n, num_segments = num_segments)
+                get_drives(self.app.pargs.target, show_n=show_n, num_segments = num_segments, filter=int(filter))
 
         if self.app.pargs.action == 'pull':
             from ..ext.aws_s3 import pull_latest
