@@ -2,6 +2,11 @@
 Operations to speed up S3 access.
 '''
 import pandas as pd
+import os
+try:
+    term_width = os.get_terminal_size().columns
+except OSError:
+    term_width = 70
 
 def urlifier(dongle, drive_time):
     """
@@ -42,7 +47,10 @@ def get_drives_df(s3_resource, bucket_name, dongle_id: str, filter=0):
     df = df[~df.key.str[-5:-1].isin(['glog','boot','rash'])]
 
     df = df.key.str.split('/', expand=True)
-    df.columns = ['dongle_id', 'drive','ext']
+    try:
+        df.columns = ['dongle_id', 'drive','ext']
+    except ValueError:
+        return pd.DataFrame([])
 
     df['date'] = df.drive.str[:10]
     df['time'] = df.drive.str[12:20]
@@ -52,14 +60,25 @@ def get_drives_df(s3_resource, bucket_name, dongle_id: str, filter=0):
     df = df.sort_values(by=['date','time'], ascending=False)
     df.seg_num = pd.to_numeric(df.seg_num, errors='coerce')
 
-    df['link'] = df.apply(lambda x: urlifier(x.dongle_id, x.drive_time), axis=1)
+    # TODO: make available
+    if filter!=0:
+        df = df[df.seg_num!=0]
+        df = df.reset_index().groupby('drive_time').max()
+        df = df[~pd.isna(df.seg_num)].reset_index()
+        
+        # set display cols according to terminal width
+        pd.set_option('display.max_colwidth',term_width)
 
-    if filter: df = df[df.seg_num!=0]
-    
     return df
 
 def get_selected_drives(s3, s3_resource, bucket_name, dongle_id, show_n):
     df = get_drives_df(s3_resource, bucket_name, dongle_id)
+
+    if len(df) == 0:
+        print(f"No files found for {dongle_id}")
+        # return two empty series of dimensions 14
+        return pd.Series(), pd.Series()
+
     latest_drive = df.iloc[0]
     last_complete_drives = df[df.seg_num!=0]
 
@@ -85,11 +104,12 @@ def get_dongle_drives(s3, s3_resource, bucket_name, dongle_id: str, show_n: int,
         else:  latest_files.append(latest_drive)
 
     df = pd.DataFrame(latest_files).reset_index()
+    df = df[~df.ext.isna()]
     return df
     
 
 def get_drives(target, bucket_name: str = 'creationlabs-raw-data', 
-                        show_n: int = 25, num_segments: int = 1):
+                        show_n: int = 25, num_segments: int = 1, filter=0):
     # TODO: profile
     # get all dongle ids
     import boto3 
@@ -105,7 +125,7 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data',
     elif target=='0':
         df = get_dongle_drives(s3, s3_resource, bucket_name, target, show_n)
     else:
-        df = get_drives_df(s3_resource, bucket_name, dongle_id=target)
+        df = get_drives_df(s3_resource, bucket_name, dongle_id=target, filter=filter)
 
     df['upload_time'] = df.drive.str.split('--').str[:-1].str.join('--')
 
@@ -117,16 +137,20 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data',
     df['time'] = df['upload_time'].apply(lambda x: humanize.naturaldelta(x))
     df = df.sort_values(by='upload_time', ascending=False)
 
-    df = df[['dongle_id','drive','time','upload_time','seg_num']]
 
-    print(df.head(show_n))
+    if target in ['0', '-1']:
+        df = df[['dongle_id','drive','time','seg_num']]
+        print(df.head(show_n))
+    else:
+        df['link'] = df.apply(lambda x: urlifier(x.dongle_id, x.drive_time), axis=1)
+        df = df[['drive_time','seg_num','link']]
+        print(df.head(show_n))
 
 def pull_latest(dongle_id):
     """
     Download the latest file in the bucket.
     """
     import boto3
-    import os
 
     bucket = 'creationlabs-raw-data'
     s3 = boto3.resource('s3')
